@@ -7,7 +7,6 @@ import time
 from datetime import datetime
 from datetime import timedelta
 import feedparser
-from appdirs import user_cache_dir
 from dateutil import parser
 
 from .ProjectHolder import ProjectHolder
@@ -60,6 +59,7 @@ class GitHubRepoSession(ProjectHolder):
         'openssl': {'repo': 'openssl/openssl'},
         'python': {'repo': 'python/cpython'},
         'cmake': {'repo': 'kitware/cmake'},
+        'kodi': {'repo': 'xbmc/xbmc'}
     }
 
     """
@@ -85,7 +85,7 @@ class GitHubRepoSession(ProjectHolder):
     def find_repo_by_name_only(self, repo):
         if repo.startswith(('https://', 'http://')):
             return None
-        cache_repo_names_file = "{}/repos.json".format(user_cache_dir("lastversion"))
+        cache_repo_names_file = "{}/repos.json".format(self.cache_dir)
         try:
             with open(cache_repo_names_file, 'r') as reader:
                 cache = json.load(reader)
@@ -173,6 +173,7 @@ class GitHubRepoSession(ProjectHolder):
         return '{}/rate_limit'.format(self.api_base)
 
     def get(self, url, **kwargs):
+        """Send GET reqiest and account for GitHub rate limits and such."""
         r = super(GitHubRepoSession, self).get(url, **kwargs)
         log.info('Got HTTP status code {} from {}'.format(r.status_code, url))
         if r.status_code == 401:
@@ -213,7 +214,7 @@ class GitHubRepoSession(ProjectHolder):
                         'Exceeded API rate limit after waiting: {}'.format(
                             r.json()['message'])
                     )
-            return self.get(url)
+                return self.get(url)
 
         if r.status_code == 403 and url != self.get_rate_limit_url():
             self.rate_limited_count = 0
@@ -277,7 +278,7 @@ class GitHubRepoSession(ProjectHolder):
             }
           }
         }
-        
+
         fragment refInfo on Ref {
           name
           target {
@@ -301,7 +302,7 @@ class GitHubRepoSession(ProjectHolder):
             }
           }
         }
-        
+
         fragment commitInfo on Commit {
           zipballUrl
           tarballUrl
@@ -311,7 +312,7 @@ class GitHubRepoSession(ProjectHolder):
             date
           }
         }
-        
+
         """
         cursor = ''
         log.info('Using graphql queries...')
@@ -630,4 +631,3 @@ class GitHubRepoSession(ProjectHolder):
             self.feed_contents[official_repo] = r.text
             return official_repo
         return None
-
