@@ -11,6 +11,7 @@ from .PypiRepoSession import PypiRepoSession
 from .SourceForgeRepoSession import SourceForgeRepoSession
 from .SystemRepoSession import SystemRepoSession
 from .WikipediaRepoSession import WikipediaRepoSession
+from .WordPressPluginRepoSession import WordPressPluginRepoSession
 from .utils import BadProjectError
 
 log = logging.getLogger(__name__)
@@ -28,7 +29,8 @@ class HolderFactory:
         'local': LocalVersionSession,
         'helm_chart': HelmChartRepoSession,
         'wiki': WikipediaRepoSession,
-        'system': SystemRepoSession
+        'system': SystemRepoSession,
+        'wp': WordPressPluginRepoSession,
     }
 
     @staticmethod
@@ -48,8 +50,10 @@ class HolderFactory:
     @staticmethod
     # go through subclasses in order to find the one that is holding a given project
     # repo is either complete URL or a name allowing to identify a single project
-    def get_instance_for_repo(repo, only=None):
-
+    def get_instance_for_repo(repo, only=None, at=None):
+        """Find the right hosting for this repo."""
+        if at == 'helm_chart' or (at and '/' not in repo):
+            return HolderFactory.HOLDERS[at](repo, hostname=None)
         holder_class = HolderFactory.HOLDERS['github']
         hostname = None
         known_repo = None
